function WebPlugins(config) {
    for (var key in config.plugins) {
        var plugin = config.plugins[key];
        switch (plugin.type) {
            case "callback":
                this[plugin.name] = this.createCallbackFunction(config, plugin.name);
                break;
            case "return":
                this[plugin.name] = this.createReturnFunction(config, plugin.name);
                break;
        }
    }
}
WebPlugins.prototype.createCallbackFunction = function (config, pluginName) {
    return function execCallback(arg1, arg2, arg3) {
        var param = {};
        var onSuccess = function () { console.debug(pluginName + " received success callback.") };
        var onError = function (errorCode) { console.debug(pluginName + " received error callback. (code=" + errorCode + ")") };
        if (arguments.length == 1) {
            if (typeof arg1 == "object") {
                param = arg1;
            } else if (typeof arg1 == "function") {
                onSuccess = arg1;
            }
        } else if (arguments.length == 2) {
            if (typeof arg1 == "object") {
                param = arg1;
                onSuccess = arg2;
            } else if (typeof arg1 == "function") {
                onSuccess = arg1;
                onError = arg2;
            }
        } else if (arguments.length == 3) {
            param = arg1;
            onSuccess = arg2;
            onError = arg3;
        }

        this[pluginName].onSuccess = onSuccess;
        this[pluginName].onError = onError;

        if (window[config.appInterfaceName] && window[config.appInterfaceName].execCallback) {
            window[config.appInterfaceName].execCallback(pluginName, JSON.stringify(param));
        } else {
            console.error("Unsupported " + config.appInterfaceName + ".execCallback(pluginName, input) interface.");
            onError("unsupported_app_interface");
        }
    }
};
WebPlugins.prototype.createReturnFunction = function (config, pluginName) {
    return function execReturn(arg1) {
        var param = {};
        if (arg1) {
            param = arg1;
        }
        if (window[config.appInterfaceName] && window[config.appInterfaceName].execReturn) {
            var result = window[config.appInterfaceName].execReturn(pluginName, JSON.stringify(param));
            try {
                return JSON.parse(result);
            } catch (error) {
                return result;
            }
        } else {
            console.error("Unsupported " + config.appInterfaceName + ".execReturn(pluginName, input) interface.");
            throw "unsupported_app_interface";
        }
    }
};
function initWebPlugins(config) {
    if (!window[config.webInterfaceName]) {
        window[config.webInterfaceName] = new WebPlugins(config);
        window.dispatchEvent(new CustomEvent('onwebpluginready'));
        console.debug("Created WebPlugins to window." + config.webInterfaceName);
    }
}
